@@ -1,7 +1,6 @@
 """Store the common business model of all entities."""
 
 import os
-import warnings
 from datetime import datetime
 from typing import Any, AnyStr, Dict, Generic, List, Optional, Union
 
@@ -28,7 +27,8 @@ class Entity(BaseModel):
     _defined_values: Dict[str, Any] = PrivateAttr()
     _skip_on_merge: List[str] = []
 
-    def __init__(self, **data: Any) -> None:
+    # ANN401: Any not allowed, but it's what we have.
+    def __init__(self, **data: Any) -> None:  # noqa: ANN401
         """Initialize the defined values."""
         super().__init__(**data)
         self._defined_values = data
@@ -57,7 +57,8 @@ class Entity(BaseModel):
         """Create an unique hash of the class object."""
         return hash(f"{self.model_name}-{self.id_}")
 
-    def __setattr__(self, attribute: str, value: Any) -> None:
+    # ANN401: Any not allowed, but it's what we have.
+    def __setattr__(self, attribute: str, value: Any) -> None:  # noqa: ANN401
         """Store the set attribute into the _defined_values."""
         if attribute != "_defined_values":
             self._defined_values[attribute] = value
@@ -66,13 +67,7 @@ class Entity(BaseModel):
     @property
     def model_name(self) -> str:
         """Return the entity model name."""
-        return self.__class__.__name__
-
-    @property
-    def _model_name(self) -> str:  # pragma: nocover
-        """Return the entity model name."""
-        warnings.warn("Use model_name instead before 2022-06-10", DeprecationWarning)
-        return self.model_name
+        return self.schema()["title"]
 
     def merge(self, other: "Entity") -> "Entity":
         """Update the attributes with the ones manually set by the user of other.
